import { Message, PermissionFlags, Snowflake } from 'discord.js';
import { IVerify } from '../structures/command/typings/IVerify';
/**
 * Set a name for the Command
 * @method Name
 * @param name {String} The name of the command
 * @returns {ClassDecorator}
 */
export declare function Name(name: string): ClassDecorator;
/**
 * Only allow the command to be executed in a guild channel
 * @method GuildOnly
 * @returns {ClassDecorator}
 */
export declare function Only(...types: string[]): ClassDecorator;
/**
 * This extends the default command verifier and the given function runs
 * BEFORE any other part of the verifier runs
 * @method Verify
 * @param func {Function} The custom verifier part you want to use
 * @returns {ClassDecorator}
 */
export declare function Verify(func: (msg: Message, client?: any) => IVerify | Promise<IVerify>): ClassDecorator;
/**
 * Throttles commands to be only usable for x times per y seconds
 * @method Throttle
 * @param interval {Number} The time in seconds
 * @param times {Number} How often the command can be executed in X seconds
 * @param [all] {Boolean} Weather to throttle all (true) users or exclude the owner
 * @returns {ClassDecorator}
 */
export declare function Throttle(interval: number, times: number, all?: boolean): ClassDecorator;
/**
 * Set the aliases for a command
 * @param aliases {String[]} The aliases to apply
 * @returns {ClassDecorator}
 */
export declare function Alias(...aliases: string[]): ClassDecorator;
/**
 * Limit command execution based on needed user permissions
 * @param perms {PermissionFlags[]} Permission Flags
 * @returns {ClassDecorator}
 */
export declare function UserPermissions(...perms: PermissionFlags[]): ClassDecorator;
/**
 * Restrict the command to users or roles which are added here
 * @param data {{roles: Snowflake[], users: Snowflake[]}}
 * @returns {ClassDecorator}
 */
export declare function Restricted(data: {
    roles: Snowflake[];
    users: Snowflake[];
}): ClassDecorator;
/**
 * Adding the command description
 * @param desc {String} The Description
 * @returns {ClassDecorator}
 */
export declare function Description(desc: string): ClassDecorator;
/**
 * Adding the Usage of a command
 * @param usage {String} The Usage
 * @returns {ClassDecorator}
 */
export declare function Usage(usage: string): ClassDecorator;
/**
 * Limiting the command to the owner
 * @returns {ClassDecorator}
 */
export declare function OwnerOnly(): ClassDecorator;
/**
 * Limit the command to NSFW channels
 * @returns {ClassDecorator}
 */
export declare function NSFW(): ClassDecorator;
/**
 * Set a minimum role for command execution
 * @param role {String|Snowflake} Min Role
 * @returns {ClassDecorator}
 */
export declare function MinRole(role: string | Snowflake): ClassDecorator;
/**
 * Hide the command from the help message
 * @returns {ClassDecorator}
 */
export declare function Hidden(): ClassDecorator;
