import { Client, ClientOptions, Snowflake } from 'discord.js';
import { CommandRegistry } from '../command/CommandRegistry';
import { EventRegistry } from '../event/EventRegistry';
import { ISilentConfig } from './typings/ISilentConfig';
/**
 * The SilentClient class
 * @extends Client
 * @class
 */
export declare class SilentClient extends Client {
    /**
     * @property {Snowflake|Snowflake[]} owner
     * @public
     */
    owner: Snowflake | Snowflake[];
    /**
     * @property {String|String[]} prefix
     * @public
     */
    prefix?: string | string[];
    /**
     * @property {Boolean} mentionPrefix
     * @public
     */
    mentionPrefix?: boolean;
    /**
     * @property {String} commandDir
     * @public
     */
    commandDir: string;
    /**
     * @property {String} eventDir
     * @public
     */
    eventDir: string;
    /**
     * @property {String} baseDir="dist/"
     * @public
     */
    baseDir: string;
    /**
     * @property {Boolean} baseCommands=true
     * @public
     */
    baseCommands: boolean;
    /**
     * @property {String} commandNotFoundError
     * @public
     */
    commandNotFoundError?: string;
    /**
     * @property {Boolean} rateLimitExceededError=true
     * @public
     */
    rateLimitExceededError: boolean;
    /**
     * @property {{showAll: boolean}} defaultHelpCommand
     * @public
     */
    defaultHelpCommand: {
        showAll: boolean;
    } | false;
    /**
     * @property {String|'mention'} defaultPrefixForce
     * @public
     */
    defaultPrefixForce: string | 'mention';
    /**
     * @property {CommandRegistry} commands
     * @public
     */
    commands: CommandRegistry;
    /**
     * @property {EventRegistry} events
     * @public
     */
    events: EventRegistry;
    /**
     * This is named _token as token is already used by discord.js itself
     * @property {String} _token
     * @private
     * @readonly
     */
    private readonly _token;
    private readonly _logger;
    constructor(silent: ISilentConfig, config?: ClientOptions);
    /**
     * Connect to the Discord API
     */
    connect(): this;
    /**
     * If multiple prefixes are set, this gets the default prefix.
     */
    readonly defaultPrefix: string;
    /**
     * Checking the configurations
     * @throws ConfigError
     * @private
     */
    checkConfig(): void;
}
