/**
 * The logger
 */
export declare class Logger {
    /**
     * Outputs the message to the console
     * @param text {String} The message to log
     * @static
     */
    private static write;
    /**
     * The name displayed when logging
     * @property {String} name
     */
    private readonly name;
    /**
     * @param name {String} The name displayed when logging something
     * @returns {Logger}
     */
    constructor(name: string);
    /**
     * Log something without any format, this equals a console.log
     * @param msg {String} The message to log
     */
    rawLog(msg: string): void;
    /**
     * Logs the error
     * @param err {String|Error} The message or error to log
     */
    error(err: string | Error): void;
    /**
     * Log the message if the log level is not restricted to errors only
     * @param text {String} The message to log
     */
    warn(text: string): void;
    /**
     * Log the message if the log level is not restricted to errors or warns only
     * @param text {String} The message to log
     */
    log(text: string): void;
    /**
     * Log the message if the log level is in debug mode
     * @param text {String} The message to log
     */
    debug(text: string): void;
    /**
     * Format a message to include the log name and the current time
     * @returns {String}
     */
    private format;
}
export declare function logger(type?: string): PropertyDecorator;
